@@ -12,6 +12,10 @@ pub enum App {
         /// Databases
         #[clap(possible_values = Database::VARIANTS, required = true)]
         database: Vec<Database>,
+
+        /// Allow specified number of parallel jobs
+        #[clap(short, long, default_value = "1")]
+        jobs: usize,
     },
 
     /// Stop playgrounds
@@ -19,9 +23,13 @@ pub enum App {
         /// Databases
         #[clap(possible_values = Database::VARIANTS, default_values = Database::VARIANTS, hide_default_value = true)]
         database: Vec<Database>,
+
+        /// Allow specified number of parallel jobs
+        #[clap(short, long, default_value = "1")]
+        jobs: usize,
     },
 
-    /// List supported backends
+    /// List supported playgrounds
     List,
 
     /// Output shell completion code
